@@ -53,8 +53,6 @@ nlmixrForget <- function(){
 ##' @importFrom stats predict logLik na.fail pchisq
 ##' @importFrom n1qn1 n1qn1
 ##' @importFrom brew brew
-##' @importFrom lattice xyplot
-##' @importFrom lattice trellis.par.get
 ##' @importFrom nlme nlme fixed.effects random.effects
 ##' @importFrom nlme groupedData
 ##' @importFrom nlme getData
@@ -64,10 +62,8 @@ nlmixrForget <- function(){
 ##' @importFrom stats as.formula nlminb optimHess rnorm terms predict anova optim sd var AIC BIC asOneSidedFormula coef end fitted resid setNames start simulate nobs qnorm quantile time
 ##' @importFrom utils assignInMyNamespace getFromNamespace head stack sessionInfo tail str
 ##' @importFrom parallel mclapply
-##' @importFrom lbfgs lbfgs
 ##' @importFrom methods is
 ##' @importFrom Rcpp evalCpp
-##' @importFrom dparser dparse
 ##' @importFrom vpc vpc
 ##' @importFrom ggplot2 ggplot aes geom_point facet_wrap geom_line geom_abline xlab geom_smooth aes_string
 ##' @importFrom RcppArmadillo armadillo_version
@@ -226,7 +222,7 @@ nlmixrData.default <- function(data, model=NULL){
     if (!is.null(model)){
         dat  <- RxODE::etTrans(data, model,addCmt=TRUE,dropUnits=TRUE,allTimeVar=TRUE)
     } else {
-        dat <- as.data.frame(data);
+        dat <- .as.data.frame(data);
     }
     return(dat);
 }
@@ -470,12 +466,12 @@ nlmixr_fit0 <- function(uif, data, est=NULL, control=list(), ...,
         model <- uif$saem.model
         inits = uif$saem.init
         if (length(uif$saem.fixed)>0) {
-			nphi = attr(model$saem_mod, "nrhs")
-			m = cumsum(!is.na(matrix(inits$theta, byrow=T, ncol=nphi)))
-			fixid = match(uif$saem.fixed, t(matrix(m,ncol=nphi)))
+            nphi = attr(model$saem_mod, "nrhs")
+            m = cumsum(!is.na(matrix(inits$theta, byrow=T, ncol=nphi)))
+            fixid = match(uif$saem.fixed, t(matrix(m,ncol=nphi)))
 
-			names(inits$theta) = rep("", length(inits$theta))
-			names(inits$theta)[fixid] = "FIXED"
+            names(inits$theta) = rep("", length(inits$theta))
+            names(inits$theta)[fixid] = "FIXED"
         }
         cfg <- configsaem(model=model, data=dat, inits=inits,
                           mcmc=mcmc, ODEopt=ODEopt, seed=seed,
@@ -509,7 +505,7 @@ nlmixr_fit0 <- function(uif, data, est=NULL, control=list(), ...,
         return(.ret);
     } else if (est == "nlme" || est == "nlme.mu" || est == "nlme.mu.cov" || est == "nlme.free"){
         if (.nTv != 0) stop("nlme does not support time-varying covariates (yet)");
-        data <- as.data.frame(data)
+        data <- .as.data.frame(data)
         if (length(uif$predDf$cond) > 1) stop("nlmixr nlme does not support multiple endpoints.")
         pt <- proc.time()
         est.type <- est;
@@ -665,8 +661,8 @@ nlmixr_fit0 <- function(uif, data, est=NULL, control=list(), ...,
                 assign("message2", fit$env$message, env);
                 assign("message", .message, env);
                 .tmp1 <- env$objDf;
-                if (any(names(.objDf) == "Condition Number")) .tmp1 <- data.frame(.tmp1, "Condition Number"=NA, check.names=FALSE);
-                if (any(names(.tmp1) == "Condition Number")) .objDf <- data.frame(.objDf, "Condition Number"=NA, check.names=FALSE);
+                if (any(names(.objDf) == "Condition Number")) .tmp1 <- .data.frame(.tmp1, "Condition Number"=NA, check.names=FALSE);
+                if (any(names(.tmp1) == "Condition Number")) .objDf <- .data.frame(.objDf, "Condition Number"=NA, check.names=FALSE);
                 env$objDf <- rbind(.tmp1, .objDf);
                 row.names(env$objDf) <- c(ifelse(est == "fo", "FOCE", "FOCEi"), "FO");
                 .tmp1 <- env$time;
@@ -762,7 +758,7 @@ nlmixr_fit  <- function(uif, data, est=NULL, control=list(), ...,
         .dataName  <- ifelse(is.null(uif$data.name),"",paste0(uif$data.name,"-"));
         if (.dataName==".-") .dataName <- ""
         .digest <- digest::digest(list(gsub("<-","=",gsub(" +","",uif$fun.txt)),
-                                       as.data.frame(uif$ini),
+                                       .as.data.frame(uif$ini),
                                        data,
                                        est,
                                        control,
@@ -798,12 +794,12 @@ nlmixr_fit  <- function(uif, data, est=NULL, control=list(), ...,
             AIC(.ret); # Calculate SAEM AIC when saving...
             .env <- .ret$env
             .extra <- (proc.time() - .nlmixrTime)["elapsed"] - sum(.env$time)
-            .env$time <- data.frame(.env$time,"other"=.extra, check.names=FALSE)
+            .env$time <- .data.frame(.env$time,"other"=.extra, check.names=FALSE)
             saveRDS(.ret,file=.saveFile)
         } else {
             .env <- .ret$env
             .extra <- (proc.time() - .nlmixrTime)["elapsed"] - sum(.env$time)
-            .env$time <- data.frame(.env$time,"other"=.extra, check.names=FALSE)
+            .env$time <- .data.frame(.env$time,"other"=.extra, check.names=FALSE)
         }
     }
     return(.ret);
@@ -1019,7 +1015,7 @@ addCwres <- function(fit, updateObject=TRUE, envir=globalenv()){
         }
     }
     .env <- .new$env
-    .env$time <- data.frame(.oTime,cwres=(proc.time() - .pt)["elapsed"],check.names=FALSE);
+    .env$time <- .data.frame(.oTime,cwres=(proc.time() - .pt)["elapsed"],check.names=FALSE);
     assign("origData", .od, .env)
     return(.new);
 }
